==> hoteldruid-mod-pt_2.1.2-2.zip: pt/messaggi.php <==
<?php

switch ($messaggio) {

case "Torna al menù principale":  		$messaggio = "Voltar ao menu principal"; break;
case "Nuovo messaggio a":  			$messaggio = "Nova mensagem para"; break;
case "da mostrare dopo le":  			$messaggio = "para mostrar depois das"; break;
case "il":  					$messaggio = "de"; break;
case "testo del messaggio":  			$messaggio = "texto da mensagem"; break;
case "Messaggi":  				$messaggio = "Mensagens"; break;
case "Spedisci":  				$messaggio = "Enviar"; break;
case "Messaggio inviato":  			$messaggio = "Mensagem enviada"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "N°":  					$messaggio = "N°"; break;
case "Mittente":  				$messaggio = "Remetente"; break;
case "Testo":  					$messaggio = "Texto"; break;
case "Data":  					$messaggio = "Data"; break;
case "Azioni":  				$messaggio = "Ações"; break;
case "Elimina":  				$messaggio = "Apagar"; break;
case "Messaggio eliminato":  			$messaggio = "Mensagem apagada"; break;
case "tutti":  					$messaggio = "todos"; break;
case "SI":  					$messaggio = "SIM"; break;
case "Si è sicuri di voler eliminare la richiesta di prenotazione di":	$messaggio = "Você tem certeza que quer apagar o pedido de reserva de"; break;
case "non ancora inserita?":  			$messaggio = "ainda não inserido?"; break;
case "Inserisci la prenotazione":  		$messaggio = "Inserir a reserva"; break;
case "Visualizza il documento":  		$messaggio = "Ver o documento"; break;
case "di tipo":  				$messaggio = "do tipo"; break;
case "Inserito":  				$messaggio = "Inserido"; break;
case "Elimina tutti i messaggi":  		$messaggio = "Apagar todas as mensagens"; break;
case "Si è sicuri di voler eliminare <div style=\"display: inline; color: red;\"><b>tutti i messaggi</b></div>":	$messaggio = "Você tem certeza que quer apagar <div style=\"display: inline; color: red;\"><b>todas as mensagens</b></div>?"; break;
case "Messaggi eliminati":  			$messaggio = "Mensagens apagadas"; break;
case "arrivati":  				$messaggio = "chegadas"; break;
case "prima del":  				$messaggio = "antes do"; break;
case "dopo il":  				$messaggio = "depois do"; break;
case "Scarica messaggi email":  		$messaggio = "Receber mesagems e-mails"; break;
case "Nessun nuovo messaggio":  		$messaggio = "Nenhuma nova mensagem"; break;
case "Nuovi messaggi":  			$messaggio = "Nova mensagem"; break;
case "Scaricati":  				$messaggio = "Recebidos"; break;
case "Connessione al server":  			$messaggio = "A conexão com o servidor"; break;
case "non riuscita!":  				$messaggio = "falhou!"; break;
case "Controllare i dati immessi in \"configura e personalizza\"":	$messaggio = "Revise as entradas em \"configurar e personalizar\""; break;
case "Dati ricavati dal messaggio email":  	$messaggio = "Dados extraidos da mensagem e-mail"; break;
case "Controlla disponibilità":  		$messaggio = "verificar disponibilidade"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "Nome":  					$messaggio = "Nome"; break;
case "Email":  					$messaggio = "E-mail"; break;
case "arrivo":  				$messaggio = "Chegada"; break;
case "partenza":  				$messaggio = "Saída"; break;
case "notti":  					$messaggio = "noites"; break;
case "persone":  				$messaggio = "pessoas"; break;
case "individui":  				$messaggio = "indivíduos"; break;
case "ospiti":  				$messaggio = "hóspedes"; break;
case "adulti":  				$messaggio = "adultos"; break;
case "bambini":  				$messaggio = "crianças"; break;
case "gruppo":  				$messaggio = "grupo"; break;
case "date":  					$messaggio = "data"; break;
case "viaggiatori":  				$messaggio = "viajantes"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-pt_3.0.8-1.zip: pt/messaggi.php <==
<?php

switch ($messaggio) {

case "Torna al menù principale":  		$messaggio = "Voltar ao menu principal"; break;
case "Nuovo messaggio a":  			$messaggio = "Nova mensagem para"; break;
case "da mostrare dopo le":  			$messaggio = "para mostrar depois das"; break;
case "il":  					$messaggio = "de"; break;
case "testo del messaggio":  			$messaggio = "texto da mensagem"; break;
case "Messaggi":  				$messaggio = "Mensagens"; break;
case "Spedisci":  				$messaggio = "Enviar"; break;
case "Messaggio inviato":  			$messaggio = "Mensagem enviada"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "N°":  					$messaggio = "N°"; break;
case "Mittente":  				$messaggio = "Remetente"; break;
case "Testo":  					$messaggio = "Texto"; break;
case "Data":  					$messaggio = "Data"; break;
case "Azioni":  				$messaggio = "Ação"; break;
case "Elimina":  				$messaggio = "Apagar"; break;
case "Messaggio eliminato":  			$messaggio = "Mensagem apagada"; break;
case "tutti":  					$messaggio = "todas"; break;
case "SI":  					$messaggio = "SIM"; break;
case "Si è sicuri di voler eliminare la richiesta di prenotazione di":	$messaggio = "Você tem certeza de que deseja apagar o pedido de reserva de"; break;
case "non ancora inserita?":  			$messaggio = "ainda não inserido?"; break;
case "Inserisci la prenotazione":  		$messaggio = "Inserir a reserva"; break;
case "Visualizza il documento":  		$messaggio = "Ver o documento"; break;
case "di tipo":  				$messaggio = "do tipo"; break;
case "Inserito":  				$messaggio = "Inserido"; break;
case "Elimina tutti i messaggi":  		$messaggio = "Apagar todas as mensagens"; break;
case "Si è sicuri di voler eliminare <div style=\"display: inline; color: red;\"><b>tutti i messaggi</b></div>":	$messaggio = "Você tem certeza de que deseja apagar <div style=\"display: inline; color: red;\"><b>todas as mensagens</b></div>"; break;
case "Messaggi eliminati":  			$messaggio = "Mensagens apagadas"; break;
case "arrivati":  				$messaggio = "chegadas"; break;
case "prima del":  				$messaggio = "antes do"; break;
case "dopo il":  				$messaggio = "depois do"; break;
case "Scarica messaggi email":  		$messaggio = "Receber mensagens e-mails"; break;
case "Nessun nuovo messaggio":  		$messaggio = "Nenhuma nova mensagem"; break;
case "Nuovi messaggi":  			$messaggio = "Novas mensagens"; break;
case "Scaricati":  				$messaggio = "Recebidos"; break;
case "Connessione al server":  			$messaggio = "A conexão com o servidor"; break;
case "non riuscita!":  				$messaggio = "falhou!"; break;
case "Controllare i dati immessi in":  		$messaggio = "Verificar os dados introduzidos no"; break;
case "configura e personalizza":  		$messaggio = "configurar e personalizar"; break;
case "Dati ricavati dal messaggio email":  	$messaggio = "Dados extraidos da mensagem e-mail"; break;
case "Controlla disponibilità":  		$messaggio = "verificar disponibilidade"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "Nome":  					$messaggio = "Nome"; break;
case "Email":  					$messaggio = "E-mail"; break;
case "arrivo":  				$messaggio = "chegada"; break;
case "partenza":  				$messaggio = "saída"; break;
case "notti":  					$messaggio = "noites"; break;
case "persone":  				$messaggio = "pessoas"; break;
case "individui":  				$messaggio = "indivíduos"; break;
case "ospiti":  				$messaggio = "hóspedes"; break;
case "adulti":  				$messaggio = "adultos"; break;
case "bambini":  				$messaggio = "crianças"; break;
case "gruppo":  				$messaggio = "grupo"; break;
case "date":  					$messaggio = "data"; break;
case "viaggiatori":  				$messaggio = "viajantes"; break;
case "periodo":  				$messaggio = "período"; break;
case "Per gli account su gmail potrebbe essere necessario abilitare l'opzione":	$messaggio = "Para contas no gmail, pode ser necessário activar a opção"; break;
case "e/o per una volta usare prima la funzione":	$messaggio = "e/ou por uma vez utilizar primeiro a função"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
